<?php
/**
 * Delete Users Page
 *
 * Copyright 2004 (c) Tim Perdue - GForge LLC
 * Copyright 2010 (c) Franck Villaume - Capgemini
 * http://fusionforge.org
 *
 * This file is part of FusionForge. FusionForge is free software;
 * you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the Licence, or (at your option)
 * any later version.
 *
 * FusionForge is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with FusionForge; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

require_once('../../../env.inc.php');
require_once $gfcommon.'include/pre.php';
require_once $gfcommon.'preplugins.php';
require_once '../mailman_utils.php';

$request =& HTTPRequest::instance();
$group_id = $request->get('group_id');
$group_list_id = $request->get('group_list_id');

session_require_perm ('project_admin', $group_id) ;

$accumulated_emails = getArrayFromRequest('accumulated_emails');

$group = group_get_object($group_id);
if (!$group || !is_object($group)) {
    exit_no_group();
} elseif ($group->isError()) {
	exit_error($group->getErrorMessage(),'admin');
}

$ml = new MailmanList($group_id,$group_list_id);

if(!$ml || !is_object($ml)) {
	$error_msg = _('Error getting the list');
	session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&error_msg='.urlencode($error_msg));
} elseif($ml->isError()) {
	$error_msg = $ml->getErrorMessage();
	session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&error_msg='.urlencode($error_msg));
} else {	
	$listname = $ml->getName();
}

$res = db_query_params('SELECT name,address FROM plugin_mailman WHERE listname=$1 AND hide=\'N\' ORDER BY name, address',
		       array($listname));

if (getStringFromRequest('finished')) {
	if (count($accumulated_emails) > 0) {
		for ($i=0; $i<count($accumulated_emails); $i++) {
			$email = $accumulated_emails[$i];
			if (!$ml->_mailingDAO->deleteSubscriber($email,$listname)) {
				$error_msg = _('Error On Update:');
				session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&error_msg='.urlencode($error_msg));
			}
		}
		$feedback =  _('Members Successfully deleted');
		Session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&feedback='.urlencode($feedback));
	} else {
		$warning_msg =  _('No member deleted');
		Session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&warning_msg='.urlencode($warning_msg));
	}
}

mailman_header(array(
'title' => _('Delete users from the list').' '.$listname,
				'help'=>'CommunicationServices.html#MailingLists',
				'admin'=>1)
);

echo '<form action="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&group_list_id='.$group_list_id.'" method="post">';

if (!$res || db_numrows($res) < 1) {
	echo _('No Matching Users Found');
} else {
	
	print '<p>';
	print _('It will take up to <span class="important">6 hours</span> for your list to be updated.');
	echo '</p>';
	
	echo '
	<p>
	'._('Check the box next to the name of the user(s) you want to delete. When done, click "Finish".').'
	</p>';

	$titles[]=_('Email');
	$titles[]=_('Real name');
	$titles[]=_('Delete Users');

	echo $HTML->listTableTop($titles);

	for ($i=0; $i<db_numrows($res); $i++) {

		$email = db_result($res,$i,'address');
		echo '<tr '. $HTML->boxGetAltRowStyle($i) . '>
			<td>'.$email.'</td>
			<td>'.db_result($res,$i,'name').'</td>
			<td><input type="checkbox" name="accumulated_emails[]" value="'. $email .'" /></td></tr>';

	}

	echo $HTML->listTableBottom();

}

echo '<p><input type="submit" name="finished" value="'._('Finish').'" /></p>
</form>';

mail_footer(array());

// Local Variables:
// mode: php
// c-file-style: "bsd"
// End:

?>
