<?php
/**
 * Finish Mass-adding users.
 *
 * Copyright 2004 (c) Tim Perdue - GForge LLC
 * Copyright 2010 (c) Franck Villaume - Capgemini
 * Copyright (C) 2011 Alain Peyrat - Alcatel-Lucent
 * http://fusionforge.org
 *
 * This file is part of FusionForge. FusionForge is free software;
 * you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the Licence, or (at your option)
 * any later version.
 *
 * FusionForge is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with FusionForge; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

require_once('../../../env.inc.php');
require_once $gfcommon.'include/pre.php';
require_once 'common/dao/CodendiDataAccess.class.php';
require_once $gfcommon.'preplugins.php';
require_once '../mailman_utils.php';

global $error_msg;

$request =& HTTPRequest::instance();
$group_id = $request->get('group_id');
$group_list_id = $request->get('group_list_id');


session_require_perm ('project_admin', $group_id) ;

$accumulated_ids = $request->get("accumulated_ids");

$group = group_get_object($group_id);
if (!$group || !is_object($group)) {
    exit_no_group();
} elseif ($group->isError()) {
	exit_error($group->getErrorMessage(),'admin');
}

$ml = new MailmanList($group_id,$group_list_id);

if(!$ml || !is_object($ml)) {
	$error_msg = _('Error getting the list');
	session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&error_msg='.urlencode($error_msg));
} elseif($ml->isError()) {
	$error_msg = $ml->getErrorMessage();
	session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&error_msg='.urlencode($error_msg));
} else {	
	$listname = $ml->getName();
}

$ids = getStringFromRequest('ids');
$good_ids = getArrayFromRequest('good_ids');

if (!$accumulated_ids) {
	if (!implode(',',$good_ids)) {
		if (!$ids) {
		    $warning_msg = _('No member added');
			session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&warning_msg='.urlencode($warning_msg));
		} else {
			$good_ids = explode(',',$ids);
		}
	} else {
		$ids = implode(',',$good_ids);
	}
} else {
	$ids = $accumulated_ids;
	$good_ids = explode(',',$accumulated_ids);
}

$res=db_query_params("SELECT user_id,user_name,realname,email,user_pw FROM users
	WHERE status='A' and type_id='1' and user_id = ANY ($1)
	ORDER BY realname ASC", array(db_int_array_to_any_clause($good_ids)));

$emails = array();
$list_email=db_query_params("SELECT email FROM users WHERE status='A' and type_id='1' and user_id = ANY ($1)", 
	array(db_int_array_to_any_clause($good_ids)));
while (  $row  =  db_fetch_array($list_email) )  {
  $emails[] = $row['email'];
}
$arr_email = array_count_values($emails);
	
if (getStringFromRequest('finished')) {
	if (db_numrows($res) == 0) {
	    $warning_msg = _('No member added');
		session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&warning_msg='.urlencode($warning_msg));		
	}
	for ($i=0; $i<db_numrows($res); $i++) {
		$email = db_result($res,$i,'email');
		$name = db_result($res,$i,'realname');	
		if ($arr_email[$email] > 1) {
			$error_msg = $email.' '._('is used by several users');
			session_redirect('/plugins/mailman/admin/finish_addusers.php?group_id='.$group_id.'&group_list_id='.$group_list_id.'&ids='.$ids.'&error_msg='.urlencode($error_msg));
		}
		$member = $ml->_mailingDAO->SearchUserByEmail($email,$listname);
		$arr_member = $member->getRow();
		if (strCmp($arr_member['name'],'') != 0) {
			$error_msg = $email.' '._('already member');
			session_redirect('/plugins/mailman/admin/finish_addusers.php?group_id='.$group_id.'&group_list_id='.$group_list_id.'&ids='.$ids.'&error_msg='.urlencode($error_msg));
		}
	}
	for ($i=0; $i<db_numrows($res); $i++) {
		$email = db_result($res,$i,'email');
		$name = db_result($res,$i,'realname');
		$password = db_result($res,$i,'user_pw');
		if (!$ml->_mailingDAO->newSubscriber($email,$name,$password,$listname,'N')) {
			$error_msg = _('Error On Update:');
			session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&error_msg='.urlencode($error_msg));
		}
	}
    $feedback = _('Members added successfully');
	session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&feedback='.urlencode($feedback));
}

mailman_header(array(
'title' => _('Add users to the list').' '.$listname,
				'help'=>'CommunicationServices.html#MailingLists',
				'admin'=>1)
);

print '<p>';
print _('It will take up to <span class="important">6 hours</span> for your list to be updated.');
echo '</p>';

echo '<form action="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&group_list_id='.$group_list_id.'" method="post">';
echo '<input type="hidden" name="good_ids" value="'. $good_ids .'" />';

if (!$res || db_numrows($res) < 1) {
	echo _('No Matching Users Found');
} else {

	$titles[]=_('Real name');
	$titles[]=_('Login');
	$titles[]=_('Email');
	$titles[]=_('Add Users');

	echo $HTML->listTableTop($titles);

	for ($i=0; $i<db_numrows($res); $i++) {
		$uid = db_result($res,$i,'user_id');

		echo '<tr '. $HTML->boxGetAltRowStyle($i) . '>
			<td>'.db_result($res,$i,'realname').'</td>
			<td>'.db_result($res,$i,'user_name').'</td>
			<td>'.db_result($res,$i,'email').'</td>
			<td><input type="checkbox" name="good_ids[]" value="'. $uid .'"';
		if (in_array($uid, $good_ids)) {
			echo ' checked="checked" ';
		}
		echo ' /></td></tr>';

	}

	echo $HTML->listTableBottom();

}

echo '<p><input type="submit" name="finished" value="'._('Finish').'" /></p>
</form>';

mail_footer(array());

// Local Variables:
// mode: php
// c-file-style: "bsd"
// End:

?>
